@@ -1,7 +1,16 @@
 import argparse
+import os
 import sys
+from typing import Iterator
 
-from pythoned import LINE_IDENTIFIER, auto_import_eval, edit, iter_identifiers
+from pythoned import (
+    LINE_IDENTIFIER,
+    auto_import_eval,
+    edit,
+    generate,
+    iter_identifiers,
+    output,
+)
 
 
 def main() -> int:
@@ -11,9 +20,10 @@ def main() -> int:
     args = arg_parser.parse_args()
     expression: str = args.expression
     if not LINE_IDENTIFIER in iter_identifiers(expression):
-        print(auto_import_eval(expression, {}))
+        for line in generate(expression):
+            print(line, end="")
     else:
-        for output_line in edit(sys.stdin, expression):
+        for output_line in edit(expression, sys.stdin):
             print(output_line, end="")
     return 0
 
